/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.bestimmungstau.parameter;

/**
 * Konstanten für die Verwendung von Parametern der Stauobjektbestimmung.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public final class SobParameterDefs {

	/**
	 * der Standardwert für den Zyklus der Stauobjektberechnung in Minuten.
	 */
	public static final int SOB_DEFAULT_ZYKLUS_IN_MINUTEN = 60;

	/**
	 * der Standardwert für die virtuelle Anfangslänge von Stauindikatoren ohne
	 * Ausdehnung in Metern.
	 */
	public static final float SOB_DEFAULT_ANFANGSLAENGE = 60;

	/**
	 * der Standardwert für den maximalen Abstand zwischen Störfallindikatoren.
	 */
	public static final float SOB_DEFAULT_MAX_SI_ABSTAND = 0;

	/**
	 * der Standardwert für die minimale Güte für die Verwendung der
	 * Indikatoren.
	 */
	public static final float SOB_DEFAULT_MIN_SI_GUETE = 0;

	/**
	 * der Standardwert für den Parameter a1 für die Bestimmung der maximalen
	 * Verlängerung eines Stauobjekts durch Prognosedaten.
	 */
	public static final float SOB_DEFAULT_PROGNOSE_A1 = 0;

	/**
	 * der Standardwert für den Parameter a2 für die Bestimmung der maximalen
	 * Verlängerung eines Stauobjekts durch Prognosedaten.
	 */
	public static final float SOB_DEFAULT_PROGNOSE_A2 = 0;

	/**
	 * der Standardwert für den Parameter a3 für die Bestimmung der maximalen
	 * Verlängerung eines Stauobjekts durch Prognosedaten.
	 */
	public static final float SOB_DEFAULT_PROGNOSE_A3 = 0;

	/**
	 * der Standardwert für die Stromabverlängerung eines Stauobjekts.
	 */
	public static final float SOB_DEFAULT_STROMAB_VERLAENGERUNG = 0;

	/**
	 * der Standardwert für die Teilungslänge eines Stauobjekts.
	 */
	public static final float SOB_DEFAULT_TEILUNGS_LAENGE = 0;

	/**
	 * der Standardwert für die Verzögerungzeit der Teilung eines Stauobjekts.
	 */
	public static final long SOB_DEFAULT_TEILUNGS_VERZOEGERUNG = 0;

	/**
	 * die PID der Attributgruppe zur Speicherung der Parameter der
	 * Stauobjektbestimmung.
	 */
	static final String ATG_NAME_STAUBESTIMMUNG_MODELL = "atg.stauBestimmungModell";

	/**
	 * der Attributname für die Speicherung der virtuelle Anfangslänge von
	 * Stauindikatoren.
	 */
	public static final String ATT_ANFANGSLAENGE = "Anfangslaenge";

	/**
	 * der Attributname für die Speicherung des Zyklus der Stauobjektberechnung.
	 */
	static final String ATT_ZYKLUS_ZEIT = "Zykluszeit";

	/**
	 * der Attributname für die Speicherung der Aspekte für die Auswahl der
	 * Verfahren der Bestimmung der Störfallsituation an den Indikatoren.
	 */
	static final String ATT_SI_VERFAHREN = "SIVerfahren";

	/**
	 * der Attributname für die Speicherung des maximalen Indikatorabstands.
	 */
	static final String ATT_MAX_SI_ABSTAND = "MaxSIAbstand";

	/**
	 * der Attributname für die Speicherung der Verzögerungszeit bei der Teilung
	 * von Stauobjekten.
	 */
	static final String ATT_TEILUNGSVERZOEGERUNG = "Teilungsverzoegerung";

	/**
	 * der Attributname für die Speicherung der Teilungslänge für Stauobjekte.
	 */
	static final String ATT_TEILUNGSLAENGE = "Teilungslaenge";

	/**
	 * der Attributname für die Speicherung der Stromabverlängerung eines
	 * Stauobjekts.
	 */
	static final String ATT_STROMAB_VERLAENGERUNG = "StromabVerlaengerung";

	/**
	 * der Attributname für die minimale Güte für einen gültigen
	 * Störfallindikator.
	 */
	static final String ATT_MIN_SI_GUETE = "MinSIGuete";

	/**
	 * der Attributname für die Speicherung des Parameters a3 für die Bestimmung
	 * der maximalen Verlängerung eines Stauobjekts durch Prognosedaten.
	 */
	static final String ATT_PROGNOSE_LAENGE_A3 = "PrognoselaengeA3";

	/**
	 * der Attributname für die Speicherung des Parameters a2 für die Bestimmung
	 * der maximalen Verlängerung eines Stauobjekts durch Prognosedaten.
	 */
	static final String ATT_PROGNOSE_LAENGE_A2 = "PrognoselaengeA2";

	/**
	 * der Attributname für die Speicherung des Parameters a1 für die Bestimmung
	 * der maximalen Verlängerung eines Stauobjekts durch Prognosedaten.
	 */
	static final String ATT_PROGNOSE_LAENGE_A1 = "PrognoselaengeA1";

	/** privater Konstruktor für Utility-Klasse. */
	private SobParameterDefs() {
		super();
	}
}
